@@ -8,7 +8,7 @@ __status__ = "Development"
 
 import numpy as np
 from scipy import constants
-from scipy.special import gamma
+from scipy.special import gamma, erf
 from scipy.misc import factorial
 from scipy import integrate
 from .particles import Molecule, MoleculeSTS
@@ -56,8 +56,7 @@ def diss_integral_rigid_sphere(T: float, deg: int, idata: np.ndarray, molecule:
                                           vl_dependent, nokt)
 
 
-def elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
-                     rig_sphere: bool=False, nokt: bool=False) -> float:
+def elastic_integral(T: float, deg: int, idata: np.ndarray, rig_sphere: bool=False, nokt: bool=False) -> float:
     """Calculates the generalized elastic omega integral either using the rigid sphere model or the VSS model
 
     Parameters
@@ -66,16 +65,8 @@ def elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float,
         the temperature of the mixture
     deg : int
         the degree of the omega integral
-    sigma : float
-        the collision diameter :math:`\\sigma_{cd}`
-    mass : float
-        the collision-reduced mass :math:`m_{cd}`
-    vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
-    vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
-    molecule : Molecule
-        the molecule which dissociates
+    idata : 1-D array-like
+        the array of interaction data
     rig_sphere : bool, optional
         if True, the the rigid sphere model is used for the crosssection, if False, the VSS model is used, defaults to
         False
@@ -87,15 +78,7 @@ def elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float,
     float
         The generalized omega integral over the elastic crosssection
     """
-    if nokt is False:
-        multiplier = ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5)
-    else:
-        multiplier = ((0.5 / (constants.pi * mass)) ** 0.5)
-    if rig_sphere is False:
-        return 0.5 * multiplier * gamma(2.0 - vsso + deg) * (constants.physical_constants['Angstrom star'][0] ** 2)\
-                   * vssc * (T ** (-vsso))
-    else:
-        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
+    return raw_elastic_integral(T, deg, idata[1], idata[0], idata[9], idata[10], rig_sphere, nokt)
 
 
 def vt_integral(T: float, deg: int, idata: np.ndarray, molecule: MoleculeSTS, i: int, delta: int,
@@ -261,13 +244,13 @@ def dE_rot_sq(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral:
     float
         The calculated averaging
     """
-    return raw_dE_rot_sq(T, idata, molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const, molecule.num_rot,
-                         full_integral, nokt)
+    return raw_dE_rot_sq(T, idata[1], idata[0], idata[9], idata[10], molecule.Z_rot(T), molecule.rot_symmetry,
+                         molecule.rot_const, molecule.num_rot, full_integral, nokt)
 
 
 def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integral: bool=True,
                   nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
+    """Calculates either the partial averaging of the change in rotational energy
     over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>_{part}`
     or the full averaging of the same quantity :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>`,
@@ -298,7 +281,7 @@ def dE_rot_single(T: float, idata: np.ndarray, molecule: MoleculeSTS, full_integ
 
 def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
                       full_integral: bool=True, nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
+    """Calculates either the partial averaging of the product of changes in rotational energy of two molecules
     over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>_{part}`
     or the full averaging of the same quantity
@@ -333,8 +316,8 @@ def dE_rot_c_dE_rot_d(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molec
 
 def dE_rot_dE_rot_full(T: float, idata: np.ndarray, molecule1: MoleculeSTS, molecule2: MoleculeSTS,
                        full_integral: bool=True, nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
-    over all one-quantum rotational transitions
+    """Calculates either the partial averaging of the product of changes in rotational energy of one molecule
+    and both molecules over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\left(\\Delta \\mathcal{E}^{rot}_{c}
     + \\Delta \\mathcal{E}^{rot}_{d} \\right)\\right>_{part}`
     or the full averaging of the same quantity
@@ -780,17 +763,17 @@ def raw_dE_rot_sq(T: float, sigma: float, mass: float, vssc: float, vsso: float,
                   * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
     tmp += integrate.quad(f, 1, molecule_num_rot)[0]
     if full_integral is False:
-        return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)
+        return 0.5 * tmp / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)
     else:
-        return tmp * 0.5 / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)\
-                   * elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)
+        return 0.5 * tmp * raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)\
+               / (Z_rot * ((constants.k * T) ** 2) * molecule_num_rot)
 
 
 def raw_dE_rot_single(T: float, sigma: float, mass: float, vssc: float, vsso: float,
                       Z_rot: float, molecule_rot_symmetry: float,
                       molecule_rot_const: float, molecule_num_rot: int, full_integral: bool=True,
                       nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
+    """Calculates either the partial averaging of the change in rotational energy
     over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>_{part}`
     or the full averaging of the same quantity :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\right>`,
@@ -827,25 +810,31 @@ def raw_dE_rot_single(T: float, sigma: float, mass: float, vssc: float, vsso: fl
     float
         The calculated averaging
     """
-    f = lambda j: (j * (j + 1) * molecule_rot_const - (j + 1) * (j + 2) * molecule_rot_const)\
-                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
-                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
-    tmp = integrate.quad(f, 0, molecule_num_rot - 1)[0]
-    # A = constants.k * T / molecule_rot_const
-    # tmp = (molecule_rot_const / molecule_rot_symmetry) * A * (A - np.exp(-molecule_num_rot * (molecule_num_rot - 1) / A)
-    #                                                           * (A + molecule_num_rot ** 2 - molecule_num_rot))
-    f = lambda j: (j * (j + 1) * molecule_rot_const - (j - 1) * j * molecule_rot_const)\
-                  * ((2.0 * j + 1.0) / molecule_rot_symmetry)\
-                  * np.exp(-j * (j + 1) * molecule_rot_const / (constants.k * T))
-    tmp += integrate.quad(f, 1, molecule_num_rot)[0]
-    # tmp += (molecule_rot_const / molecule_rot_symmetry) * A\
-    #        * ((A + 2.0) * np.exp(-2.0 / A) - np.exp(-molecule_num_rot * (molecule_num_rot + 1) / A)
-    #                     * (A + molecule_num_rot ** 2 + molecule_num_rot))
+    A = constants.k * T / molecule_rot_const
+    Asqrt = A ** 0.5
+    prettyexp = np.exp(-molecule_num_rot * (molecule_num_rot - 1) / A)
+    prettyexp2 = 1.0 / prettyexp
+
+    prettyerf = erf(0.5 / Asqrt)
+    prettyerf2 = erf((-1.0 + 2 * molecule_num_rot) / (2.0 * Asqrt))
+    tmp = A * (A - prettyexp * (A + molecule_num_rot ** 2 - molecule_num_rot))
+    tmp -= prettyexp * (A * (A + 2.0) * prettyexp2 - A * (A + molecule_num_rot + molecule_num_rot ** 2)
+                        + (A ** 1.5) * np.exp(((1.0 - 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
+                        * (constants.pi ** 0.5) * (-prettyerf + prettyerf2))
+    tmp += A * ((A + 2.0) * np.exp(-2.0 / A) - np.exp(-molecule_num_rot * (molecule_num_rot + 1) / A)
+                          * (A + molecule_num_rot ** 2 + molecule_num_rot))
+    tmp -= A * (np.exp(-2.0 / A) * (A + (Asqrt * np.exp(2.25 / A)) * (constants.pi ** 0.5)
+                * erf(1.5 / Asqrt)) - np.exp(-molecule_num_rot * (1.0 + molecule_num_rot) / A)
+                * (A + (-1.0 + molecule_num_rot) * molecule_num_rot + Asqrt
+                   * np.exp(((1.0 + 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
+                   * (constants.pi ** 0.5) * erf((1.0 + 2.0 * molecule_num_rot) / (2.0 * Asqrt))))
+    tmp *= molecule_rot_const / molecule_rot_symmetry
+
     if full_integral is False:
-        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot)
+        return 0.5 * tmp / (Z_rot * constants.k * T * molecule_num_rot)
     else:
-        return tmp * 0.5 / (Z_rot * constants.k * T * molecule_num_rot)\
-                   * elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)
+        return 0.5 * tmp * raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, nokt=nokt)\
+               / (Z_rot * constants.k * T * molecule_num_rot)
 
 
 def raw_dE_rot_c_dE_rot_d(T: float, sigma: float, mass: float, vssc: float, vsso: float,
@@ -853,7 +842,7 @@ def raw_dE_rot_c_dE_rot_d(T: float, sigma: float, mass: float, vssc: float, vsso
                           molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
                           molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
                           nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
+    """Calculates either the partial averaging of the product of changes in rotational energy of two molecules
     over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\Delta \\mathcal{E}^{rot}_{d}\\right>_{part}`
     or the full averaging of the same quantity
@@ -911,8 +900,8 @@ def raw_dE_rot_dE_rot_full(T: float, sigma: float, mass: float, vssc: float, vss
                            molecule_rot_symmetry2: float, molecule_rot_const1: float, molecule_rot_const2: float,
                            molecule_num_rot1: int, molecule_num_rot2: int, full_integral: bool=True,
                            nokt: bool=False) -> float:
-    """Calculates either the partial averaging of the squared change in rotational energy
-    over all one-quantum rotational transitions
+    """Calculates either the partial averaging of the product of changes in rotational energy of one molecule
+    and both molecules over all one-quantum rotational transitions
     :math:`\\left<\\Delta \\mathcal{E}^{rot}_{c}\\left(\\Delta \\mathcal{E}^{rot}_{c}
     + \\Delta \\mathcal{E}^{rot}_{d} \\right)\\right>_{part}`
     or the full averaging of the same quantity
@@ -966,4 +955,45 @@ def raw_dE_rot_dE_rot_full(T: float, sigma: float, mass: float, vssc: float, vss
                                molecule_num_rot1, full_integral, nokt) \
                                                 * raw_dE_rot_single(T, sigma, mass, vssc, vsso, Z_rot2,
                                                                     molecule_rot_symmetry2, molecule_rot_const2,
-                                                                    molecule_num_rot2, False, False)
\ No newline at end of file
+                                                                    molecule_num_rot2, False, False)
+
+
+def raw_elastic_integral(T: float, deg: int, sigma: float, mass: float, vssc: float, vsso: float,
+                         rig_sphere: bool=False, nokt: bool=False) -> float:
+    """Calculates the generalized elastic omega integral either using the rigid sphere model or the VSS model,
+    *raw* version
+
+    Parameters
+    ----------
+    T : float
+        the temperature of the mixture
+    deg : int
+        the degree of the omega integral
+    sigma : float
+        the collision diameter :math:`\\sigma_{cd}`
+    mass : float
+        the collision-reduced mass :math:`m_{cd}`
+    vssc : float
+        the elastic crosssection VSS potential :math:`C` parameter
+    vsso : float
+        the elastic crosssection VSS potential :math:`\\omega` parameter
+    rig_sphere : bool, optional
+        if True, the the rigid sphere model is used for the crosssection, if False, the VSS model is used, defaults to
+        False
+    nokt : bool, optional
+        if True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+
+    Returns
+    -------
+    float
+        The generalized omega integral over the elastic crosssection
+    """
+    if nokt is False:
+        multiplier = ((T * constants.k / (2.0 * constants.pi * mass)) ** 0.5)
+    else:
+        multiplier = ((0.5 / (constants.pi * mass)) ** 0.5)
+    if rig_sphere is False:
+        return 0.5 * multiplier * gamma(2.0 - vsso + deg) * (constants.physical_constants['Angstrom star'][0] ** 2)\
+                   * vssc * (T ** (-vsso))
+    else:
+        return 0.5 * multiplier * constants.pi * gamma(0.5 * deg + 2.0) * (sigma ** 2)
\ No newline at end of file
