@@ -65,19 +65,24 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
     next(csv_file_object)
     res = np.zeros(16)
     res[:3] = [m, sigma, eps]
+    found = False
 
     for row in csv_file_object:
-        if (row[0] == partner1.name and row[1] == partner2.name) or\
-                (row[1] == partner1.name and row[0] == partner2.name):
+        if found is False and ((row[0] == partner1.name and row[1] == partner2.name)
+                               or (row[1] == partner1.name and row[0] == partner2.name)):
+            found = True
             rd = np.array(row[2:]).astype(np.float64)
             # res[3:] = [rd[0], rd[1], rd[2], rd[3], rd[4], rd[5], rd[6], rd[7], rd[8], rd[9]]
             res[3:] = rd[:]
 
-    res[3] *= constants.physical_constants['electron volt'][0] / constants.k
-    res[4] *= 1.0 / constants.physical_constants['Angstrom star'][0]
-    res[14] *= constants.physical_constants['electron volt'][0] / 1000.0
-    res[15] *= constants.physical_constants['Angstrom star'][0]
-    return res
+    if found is False:
+        raise KineticlibError('No interaction data found for particles ' + partner1.name + ', ' + partner2.name)
+    else:
+        res[3] *= constants.physical_constants['electron volt'][0] / constants.k
+        res[4] *= 1.0 / constants.physical_constants['Angstrom star'][0]
+        res[14] *= constants.physical_constants['electron volt'][0] / 1000.0
+        res[15] *= constants.physical_constants['Angstrom star'][0]
+        return res
 
 
 def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np.ndarray:
@@ -118,5 +123,5 @@ def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np
             res[1] *= (10 ** 16) / constants.N_A
             return res
     if found is False:
-        raise KineticlibError('No dissociation data found for the reaction partners '
+        raise KineticlibError('No dissociation data found for particles '
                               + molecule_name + ', ' + partner_name)
\ No newline at end of file
