@@ -9,7 +9,6 @@ __status__ = "Development"
 import numpy as np
 from scipy import constants
 from scipy.misc import factorial
-from .particles import MoleculeSTS
 from .errors import KineticlibError
 
 
@@ -150,11 +149,10 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
         s = -delta * 1.0
         ns = fact_div_fact(i + delta, i)
 
-    omega = np.absolute((ve_before - ve_after) / delta) / constants.hbar
+    omega = abs((ve_before - ve_after) / delta) / constants.hbar
     if omega == 0.0:
         return 0.0
-    g *= (2 * constants.k * T / mass) ** 0.5
-    vel = vel_avg_vt(g, ve_before, ve_after, mass)
+    vel = vel_avg_vt(g * (2 * constants.k * T / mass) ** 0.5, ve_before, ve_after, mass)
 
     if vel < 0.0:
         return 0.0
@@ -163,8 +161,7 @@ def vt_probability(g: float, T: float, mass: float, beta: float, ve_before: floa
     eps = (np.cosh((1.0 + phi) * omega / (beta * vel))
            / (np.sinh(2.0 * constants.pi * omega / (beta * vel)))) ** 2
     eps *= 4.0 * svt * (constants.pi ** 2) * omega * mass / ((beta ** 2) * constants.h)
-    prob = ns * (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
-    return prob
+    return ns * (eps ** s) * np.exp(- 2.0 * (ns ** (1.0 / s)) * eps / (s + 1)) / (factorial(s) ** 2)
 
 
 def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: float, ve_after: float, i: int, delta: int,
@@ -200,8 +197,7 @@ def vt_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before: floa
     """
     svt = 0.5
 
-    g *= (2 * constants.k * T / mass) ** 0.5
-    vel = vel_avg_vt(g, ve_before, ve_after, mass)
+    vel = vel_avg_vt(g * (2 * constants.k * T / mass) ** 0.5, ve_before, ve_after, mass)
     if vel < 0.0:
         return 0.0
 
@@ -287,23 +283,22 @@ def vv_probability(g: float, T: float, mass: float, beta: float, ve_before1: flo
         ns1 = fact_div_fact(i + i_delta, i)
         ns2 = fact_div_fact(k, k - i_delta)
 
-    g *= (2.0 * constants.k * T / mass) ** 0.5
-    vel = vel_avg_vv(g, ve_before1, ve_after2, ve_before2, ve_after2, mass)
+    vel = vel_avg_vv(g * (2.0 * constants.k * T / mass) ** 0.5, ve_before1, ve_after2, ve_before2, ve_after2, mass)
 
     if vel < 0:
         return 0.0
 
-    omega1 = np.absolute((ve_before1 - ve_after1) / i_delta) / constants.hbar
-    omega2 = np.absolute((ve_before2 - ve_after2) / i_delta) / constants.hbar
+    omega1 = abs((ve_before1 - ve_after1) / i_delta) / constants.hbar
+    omega2 = abs((ve_before2 - ve_after2) / i_delta) / constants.hbar
 
     if omega1 == 0.0 or omega2 == 0:
         return 0.0
 
-    xi = 2 * np.abs(omega1 - omega2) / (beta * vel)
+    xi = 2 * abs(omega1 - omega2) / (beta * vel)
     if xi < 1.0 ** (-4):
         rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
     else:
-        rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+        rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
     return rhoxi * ns1 * ns2 * np.exp(-2.0 * rhoxi * ((ns1 * ns2) ** (1.0 / s)) / (s + 1)) / (factorial(s) ** 2)
 
@@ -344,15 +339,14 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         Velocity-dependent part of the VV transition probability
     """
     svv = 0.04
-    g *= (2.0 * constants.k * T / mass) ** 0.5
-    vel = vel_avg_vv(g, ve_before1, ve_after2, ve_before2, ve_after2, mass)
+    vel = vel_avg_vv(g * (2.0 * constants.k * T / mass) ** 0.5, ve_before1, ve_after2, ve_before2, ve_after2, mass)
     if vel < 0:
         return 0.0
 
     if i_delta == 1:
         omega1 = (ve_after1 - ve_before1) / constants.hbar
         omega2 = (ve_before2 - ve_after2) / constants.hbar
-        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
+        xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
@@ -362,7 +356,7 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
     elif i_delta == -1:
         omega1 = (ve_before1 - ve_after1) / constants.hbar
         omega2 = (ve_after2 - ve_before2) / constants.hbar
-        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
+        xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
@@ -374,12 +368,12 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         s = i_delta * 1.0
         omega1 = (ve_after1 - ve_before1) / constants.hbar
         omega2 = (ve_before2 - ve_after2) / constants.hbar
-        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
+        xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
         return rhoxi * np.exp(-2.0 * ((fact_div_fact(i, i + i_delta) * fact_div_fact(k - i_delta, k)) ** (1.0 / s))
                      * rhoxi / (s + 1))
@@ -387,12 +381,12 @@ def vv_prob_g_only(g: float, T: float, mass: float, beta: float, ve_before1: flo
         s = -i_delta * 1.0
         omega1 = (ve_before1 - ve_after1) / constants.hbar
         omega2 = (ve_after2 - ve_before2) / constants.hbar
-        xi = 2.0 * np.abs(omega1 - omega2) / (beta * vel)
+        xi = 2.0 * abs(omega1 - omega2) / (beta * vel)
 
         if xi < 1.0 ** (-10):
             rhoxi = 0.25 * svv * ((beta * vel) ** 2) / (omega1 * omega2)
         else:
-            rhoxi = svv * (np.abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
+            rhoxi = svv * (abs(omega1 - omega2) ** 2) / (omega1 * omega2 * (np.sinh(xi) ** 2))
 
         return rhoxi * np.exp(-2.0 * ((fact_div_fact(i + i_delta, i) * fact_div_fact(k, k - i_delta)) ** (1.0 / s))
                      * rhoxi / (s + 1))
\ No newline at end of file
